EXPORTS
	??1CLineEditor@@UAE@XZ @ 1 NONAME ; CLineEditor::~CLineEditor(void)
	?HandleKey@CLineEditor@@QAEXII@Z @ 2 NONAME ; void CLineEditor::HandleKey(unsigned int, unsigned int)
	?NewL@CLineEditor@@SAPAV1@AAVRFs@@AAVMAbstractConsoleWriter@@AAVMLineEditorObserver@@AAVMLineCompleter@@@Z @ 3 NONAME ABSENT; class CLineEditor * CLineEditor::NewL(class RFs &, class MAbstractConsoleWriter &, class MLineEditorObserver &, class MLineCompleter &)
	?Start@CLineEditor@@QAEXABVTDesC16@@@Z @ 4 NONAME ; void CLineEditor::Start(class TDesC16 const &)
	??0TConsoleLine@@QAE@AAVRConsole@@@Z @ 5 NONAME ; TConsoleLine::TConsoleLine(class RConsole &)
	?Contents@TConsoleLine@@QBE?AVTPtrC16@@XZ @ 6 NONAME ; class TPtrC16 TConsoleLine::Contents(void) const
	?ContentsToCursor@TConsoleLine@@QBE?AVTPtrC16@@XZ @ 7 NONAME ; class TPtrC16 TConsoleLine::ContentsToCursor(void) const
	?CursorBeginning@TConsoleLine@@QAEXXZ @ 8 NONAME ; void TConsoleLine::CursorBeginning(void)
	?CursorEnd@TConsoleLine@@QAEXXZ @ 9 NONAME ; void TConsoleLine::CursorEnd(void)
	?CursorLeft@TConsoleLine@@QAEXXZ @ 10 NONAME ; void TConsoleLine::CursorLeft(void)
	?CursorNextWord@TConsoleLine@@QAEXXZ @ 11 NONAME ; void TConsoleLine::CursorNextWord(void)
	?CursorPreviousWord@TConsoleLine@@QAEXXZ @ 12 NONAME ; void TConsoleLine::CursorPreviousWord(void)
	?CursorRight@TConsoleLine@@QAEXXZ @ 13 NONAME ; void TConsoleLine::CursorRight(void)
	?DeleteLeft@TConsoleLine@@QAEXXZ @ 14 NONAME ; void TConsoleLine::DeleteLeft(void)
	?DeleteRight@TConsoleLine@@QAEXXZ @ 15 NONAME ; void TConsoleLine::DeleteRight(void)
	?End@TConsoleLine@@QAEXXZ @ 16 NONAME ; void TConsoleLine::End(void)
	?Insert@TConsoleLine@@QAEXVTChar@@@Z @ 17 NONAME ; void TConsoleLine::Insert(class TChar)
	?Overwrite@TConsoleLine@@QAEXVTChar@@@Z @ 18 NONAME ; void TConsoleLine::Overwrite(class TChar)
	?PrintCompletionPossibilitiesL@TConsoleLine@@QAEXABVTDesC16@@@Z @ 19 NONAME ; void TConsoleLine::PrintCompletionPossibilitiesL(class TDesC16 const &)
	?Redraw@TConsoleLine@@QAEXXZ @ 20 NONAME ; void TConsoleLine::Redraw(void)
	?Replace@TConsoleLine@@QAEXABVTDesC16@@@Z @ 21 NONAME ; void TConsoleLine::Replace(class TDesC16 const &)
	?Replace@TConsoleLine@@QAEXHABVTDesC16@@@Z @ 22 NONAME ; void TConsoleLine::Replace(int, class TDesC16 const &)
	?Start@TConsoleLine@@QAEXABVTDesC16@@@Z @ 23 NONAME ; void TConsoleLine::Start(class TDesC16 const &)
	?NewL@CLineEditor@@SAPAV1@AAVRFs@@AAVMAbstractConsoleWriter@@AAVMLineEditorObserver@@AAVMLineCompleter@@ABVTDesC16@@@Z @ 24 NONAME ; class CLineEditor * CLineEditor::NewL(class RFs &, class MAbstractConsoleWriter &, class MLineEditorObserver &, class MLineCompleter &, class TDesC16 const &)
	?ReinstatePromptAndUserInput@CLineEditor@@QAEXXZ @ 25 NONAME ; void CLineEditor::ReinstatePromptAndUserInput(void)
	?RemovePromptAndUserInput@CLineEditor@@QAEXXZ @ 26 NONAME ; void CLineEditor::RemovePromptAndUserInput(void)
	??0TIoConsWriterAdaptor@@QAE@AAVRIoConsoleWriteHandle@@@Z @ 27 NONAME ; TIoConsWriterAdaptor::TIoConsWriterAdaptor(class RIoConsoleWriteHandle &)
	??0TConsoleBaseAdaptor@@QAE@AAVCConsoleBase@@@Z @ 28 NONAME ; TConsoleBaseAdaptor::TConsoleBaseAdaptor(class CConsoleBase &)
	?Start@CLineEditor@@QAEXABVTDesC16@@0@Z @ 29 NONAME ; void CLineEditor::Start(class TDesC16 const &, class TDesC16 const &)
	?Start@TConsoleLine@@QAEXABVTDesC16@@0@Z @ 30 NONAME ; void TConsoleLine::Start(class TDesC16 const &, class TDesC16 const &)
	?Redraw@CLineEditor@@QAEXXZ @ 31 NONAME ; void CLineEditor::Redraw(void)
	?Abort@CLineEditor@@QAEXXZ @ 32 NONAME ; void CLineEditor::Abort(void)

